#include <AccelStepper.h>
#include <Wire.h>

// Definir pines para DIR y STEP
#define DIR_PIN D2
#define STEP_PIN D1

// Crear un objeto de AccelStepper
AccelStepper stepper(1, STEP_PIN, DIR_PIN);

// Definir el número de pasos por revolución (200 pasos en un motor de 1.8 grados por paso)
#define STEPS_PER_REV 200

// Variable para almacenar el tiempo en que se recibió la señal
unsigned long signalReceivedTime = 0;

// Bandera para indicar si el motor debe regresar a home
bool returnToHome = false;

void setup() {
  Serial.begin(9600); // Inicializar la comunicación serial para depuración

  // Establecer la velocidad máxima y la aceleración
  stepper.setMaxSpeed(500); // Velocidad máxima en pasos por segundo
  stepper.setAcceleration(250); // Aceleración en pasos por segundo al cuadrado

  // Mover a la posición inicial
  stepper.setCurrentPosition(0);
  Serial.println("Setup completado");
}

void loop() {
  // Verificar si hay datos disponibles en el puerto serial
  if (Serial.available() > 0) {
    // Leer el dato recibido
    int signal = Serial.parseInt();

    // Determinar el número de pasos en función de la señal recibida
    int steps = 0;
    if (signal == 1) {
      steps = STEPS_PER_REV / 4; // 90 grados
      Serial.println("Girando 90 grados");
      signalReceivedTime = millis(); // Registrar el tiempo en que se recibió la señal
      returnToHome = true;
    } else if (signal == 2) {
      steps = STEPS_PER_REV / 2; // 180 grados
      Serial.println("Girando 180 grados");
      signalReceivedTime = millis(); // Registrar el tiempo en que se recibió la señal
      returnToHome = true;
    } else if (signal == 3) {
      steps = (3 * STEPS_PER_REV) / 4; // 270 grados
      Serial.println("Girando 270 grados");
      signalReceivedTime = millis(); // Registrar el tiempo en que se recibió la señal
      returnToHome = true;
    } else if (signal == 0) {
      steps = 0;
      Serial.println("Volviendo a la posición inicial");
      signalReceivedTime = millis(); // Registrar el tiempo en que se recibió la señal
      returnToHome = true;
    } else {
      Serial.println("Señal no válida");
    }

    // Mover el motor al número de pasos calculado
    stepper.moveTo(steps);
    stepper.runToPosition();
  }

  // Verificar si ha pasado un minuto desde que se recibió la señal
  if (returnToHome && (millis() - signalReceivedTime >= 60000)) {
    Serial.println("Regresando a la posición inicial automáticamente");
    stepper.moveTo(0);
    stepper.runToPosition();
    returnToHome = false; // Reiniciar la bandera
  }

  // Esperar un momento antes de la próxima lectura
  delay(100); // 0.1 segundo de espera para evitar lecturas rápidas sucesivas
}
